@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: void
 version: 0.7.1
-id: void-0.7.1-9c9ef5053011ca6c1b107003e36c68b3
-key: void_7fJFaGv6GFl6303F6YLNf6
+id: void-0.7.1-5744fee86c2ab4bfc1ef174bfe8d8c9d
+key: void_9aMO4kGPBJM4OrYCfwbx4Z
 license: BSD3
 copyright: Copyright (C) 2008-2015 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -21,13 +21,13 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/void-0.7.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/void-0.7.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/void-0.7.1
-hs-libraries: HSvoid-0.7.1-7fJFaGv6GFl6303F6YLNf6
+hs-libraries: HSvoid-0.7.1-9aMO4kGPBJM4OrYCfwbx4Z
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
-    hashable-1.2.4.0-44b2533f61c94bc76cb2b27e15566721
-    semigroups-0.18.0.1-09717ed0a84e1dbeffebbb54d604d271
+    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
+    semigroups-0.18.0.1-8982ad8edd41304214263f489c2b00c2
 haddock-interfaces: /usr/share/doc/haskell-void/html/void.haddock
 haddock-html: /usr/share/doc/haskell-void/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
